Introduction
============

`named-arrays` is an implementation of a
`named tensor <https://nlp.seas.harvard.edu/NamedTensor>`_
that includes first-class support for :class:`astropy.units.Quantity` along
with many other useful features such as representations of
scalars, vectors, and matrices.

API Reference
=============

An in-depth description of the classes and functions defined in the this library.

.. autosummary::
    :toctree: _autosummary
    :template: module_custom.rst
    :recursive:

    named_arrays

Tutorials
=========

Jupyter notebook examples on how to use :mod:`named_arrays`.

.. toctree::
    :maxdepth: 1

    tutorials/PolynomialFunctionArray


References
==========

.. bibliography::

|


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
